package cn.iocoder.yudao.module.system.job.birthday;

import cn.iocoder.yudao.framework.tenant.core.job.TenantJob;
import cn.iocoder.yudao.module.system.dal.dataobject.user.AdminUserDO;
import cn.iocoder.yudao.module.system.dal.mysql.user.AdminUserMapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.xxl.job.core.biz.model.ReturnT;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;

@Component
@Slf4j
@EnableScheduling
public class BirthdayJob {


    @Resource
    private AdminUserMapper adminUserMapper;

    /**
     * 生日提醒
     *
     * @return
     */
    @XxlJob("birthdayJob")
    @TenantJob // --- ⚠️ 这个注解 会将租户列表拉出来 完了后逐个租户执行 定时任务需要注意
    public ReturnT<String> execute() {
        String time = LocalDateTime.now().format(DateTimeFormatter.ofPattern("MM-dd"));
        // -- 获取当天月日 生日的人员列表
        List<AdminUserDO> list = adminUserMapper.selectList(new LambdaQueryWrapper<AdminUserDO>()
                .like(AdminUserDO::getBirthdayDay, time));
        if (!list.isEmpty()) {
            // TODO: 2024/9/2 发送短信未指定人
            log.info("生日提醒，生日为{}，人员为{}", time, list);
        }
        // 返回执行成功
        return ReturnT.SUCCESS;
    }
}
