package cn.iocoder.yudao.module.smartfactory.service.factorydata;

import cn.iocoder.yudao.module.smartfactory.controller.admin.factorydata.vo.FactoryDataInfoRespVO;
import cn.iocoder.yudao.module.smartfactory.controller.admin.factorydata.vo.sizeData.FactoryDataSizeCreateReqVO;
import cn.iocoder.yudao.module.smartfactory.controller.admin.factorydata.vo.sizeData.FactoryDataSizeTotalVO;
import cn.iocoder.yudao.module.smartfactory.dal.dataobject.factorydata.FactoryDataSizeDO;

import javax.validation.Valid;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

/**
 * 工厂出库入库规格数据 Service 接口
 *
 * @author 符溶馨
 */
public interface FactoryDataSizeService {

    /**
     * 创建工厂规格数据
     *
     * @param createReqVO 创建信息
     * @return 编号
     */
    Long createData(@Valid FactoryDataSizeCreateReqVO createReqVO) throws Exception;

    /**
     * 更新工厂规格数据
     *
     * @param updateReqVO 更新信息
     */
    void updateData(@Valid FactoryDataSizeCreateReqVO updateReqVO) throws Exception;

    /**
     * 删除工厂规格数据
     *
     * @param factoryId 工厂编号
     * @param date 日期
     */
    void deleteData(Long factoryId, String date);

    /**
     * 获得出入库规格数据 列表
     * @return 出入库规格数据
     */
    List<FactoryDataInfoRespVO> getDetailList(Long factoryId, LocalDate[] date, LocalDateTime[] createTime);

    /**
     * 获得指定时间段内 出入库规格数据之和
     * @param dateTimes 时间区间
     * @return 出入库规格数据之和
     */
    List<FactoryDataInfoRespVO> getSUMByDateTimes(LocalDateTime[] dateTimes);

    /**
     * 获得指定工厂上一次录入的规格信息
     * @param factoryId 工厂编号
     * @param dataTypes 数据类型
     * @return 规格详情列表
     */
    List<FactoryDataSizeDO> getLastSize(Long factoryId, List<Integer> dataTypes);

    /**
     * 获得指定工厂指定日期内，出入库规格明细详情
     * @param factoryId 工厂编号
     * @param date 日期
     * @return 出入库规格明细详情
     */
    List<FactoryDataSizeTotalVO> getSizeTotalByFactory(Long factoryId, LocalDate[] date);
}
